package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.OneClickTakeoffMapper;
import com.ruoyi.system.domain.OneClickTakeoff;
import com.ruoyi.system.service.IOneClickTakeoffService;

/**
 * 一键起飞Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-09
 */
@Service
public class OneClickTakeoffServiceImpl implements IOneClickTakeoffService 
{
    @Autowired
    private OneClickTakeoffMapper oneClickTakeoffMapper;

    /**
     * 查询一键起飞
     * 
     * @param id 一键起飞主键
     * @return 一键起飞
     */
    @Override
    public OneClickTakeoff selectOneClickTakeoffById(Long id)
    {
        return oneClickTakeoffMapper.selectOneClickTakeoffById(id);
    }

    /**
     * 查询一键起飞列表
     * 
     * @param oneClickTakeoff 一键起飞
     * @return 一键起飞
     */
    @Override
    public List<OneClickTakeoff> selectOneClickTakeoffList(OneClickTakeoff oneClickTakeoff)
    {
        return oneClickTakeoffMapper.selectOneClickTakeoffList(oneClickTakeoff);
    }

    /**
     * 新增一键起飞
     * 
     * @param oneClickTakeoff 一键起飞
     * @return 结果
     */
    @Override
    public int insertOneClickTakeoff(OneClickTakeoff oneClickTakeoff)
    {
        return oneClickTakeoffMapper.insertOneClickTakeoff(oneClickTakeoff);
    }

    /**
     * 修改一键起飞
     * 
     * @param oneClickTakeoff 一键起飞
     * @return 结果
     */
    @Override
    public int updateOneClickTakeoff(OneClickTakeoff oneClickTakeoff)
    {
        return oneClickTakeoffMapper.updateOneClickTakeoff(oneClickTakeoff);
    }

    /**
     * 批量删除一键起飞
     * 
     * @param ids 需要删除的一键起飞主键
     * @return 结果
     */
    @Override
    public int deleteOneClickTakeoffByIds(Long[] ids)
    {
        return oneClickTakeoffMapper.deleteOneClickTakeoffByIds(ids);
    }

    /**
     * 删除一键起飞信息
     * 
     * @param id 一键起飞主键
     * @return 结果
     */
    @Override
    public int deleteOneClickTakeoffById(Long id)
    {
        return oneClickTakeoffMapper.deleteOneClickTakeoffById(id);
    }
}
